@@ -8,14 +8,18 @@ shinyApp(
     dashboardSidebar(),
     dashboardBody(
       box(
-        title = "Closable Box with dropdown", 
+        title = "Closable Box with dropdown",
         width = 12,
-        status = "warning", 
-        solidHeader = FALSE, 
+        status = "warning",
+        solidHeader = FALSE,
         collapsible = TRUE,
         dropdownMenu = boxDropdown(
           icon = icon("wrench", class = "fa-2x"),
-          boxDropdownItem("Click me", id = "dropdownItem", icon = icon("heart")),
+          boxDropdownItem(
+            "Click me",
+            id = "dropdownItem",
+            icon = icon("heart")
+          ),
           boxDropdownItem("item 2", href = "https://www.google.com/"),
           dropdownDivider(),
           boxDropdownItem("item 3", icon = icon("table-cells"))
